Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(729)

Unified Diff: net/socket/socket_test_util.cc

Issue 2351513002: net: rename BoundNetLog to NetLogWithSource (Closed)
Patch Set: one more fix, content bound_net_log_ Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/socket/socket_test_util.cc
diff --git a/net/socket/socket_test_util.cc b/net/socket/socket_test_util.cc
index 1bc26225487fa2e810175d98decd08424f74e45a..4b263de33b58feec7856acec2a79476ce4be9448 100644
--- a/net/socket/socket_test_util.cc
+++ b/net/socket/socket_test_util.cc
@@ -755,10 +755,8 @@ std::unique_ptr<SSLClientSocket> MockClientSocketFactory::CreateSSLClientSocket(
void MockClientSocketFactory::ClearSSLSessionCache() {
}
-MockClientSocket::MockClientSocket(const BoundNetLog& net_log)
- : connected_(false),
- net_log_(net_log),
- weak_factory_(this) {
+MockClientSocket::MockClientSocket(const NetLogWithSource& net_log)
+ : connected_(false), net_log_(net_log), weak_factory_(this) {
peer_addr_ = IPEndPoint(IPAddress(192, 0, 2, 33), 0);
}
@@ -794,7 +792,7 @@ int MockClientSocket::GetLocalAddress(IPEndPoint* address) const {
return OK;
}
-const BoundNetLog& MockClientSocket::NetLog() const {
+const NetLogWithSource& MockClientSocket::NetLog() const {
return net_log_;
}
@@ -863,7 +861,7 @@ void MockClientSocket::RunCallback(const CompletionCallback& callback,
MockTCPClientSocket::MockTCPClientSocket(const AddressList& addresses,
net::NetLog* net_log,
SocketDataProvider* data)
- : MockClientSocket(BoundNetLog::Make(net_log, NetLogSourceType::NONE)),
+ : MockClientSocket(NetLogWithSource::Make(net_log, NetLogSourceType::NONE)),
addresses_(addresses),
data_(data),
read_offset_(0),
@@ -1135,7 +1133,8 @@ MockSSLClientSocket::MockSSLClientSocket(
const SSLConfig& ssl_config,
SSLSocketDataProvider* data)
: MockClientSocket(
// Have to use the right BoundNetLog for LoadTimingInfo regression
// tests.
transport_socket->socket()->NetLog()),
transport_(std::move(transport_socket)),
@@ -1260,7 +1259,7 @@ MockUDPClientSocket::MockUDPClientSocket(SocketDataProvider* data,
network_(NetworkChangeNotifier::kInvalidNetworkHandle),
pending_read_buf_(NULL),
pending_read_buf_len_(0),
- net_log_(BoundNetLog::Make(net_log, NetLogSourceType::NONE)),
+ net_log_(NetLogWithSource::Make(net_log, NetLogSourceType::NONE)),
weak_factory_(this) {
DCHECK(data_);
data_->Initialize(this);
@@ -1353,7 +1352,7 @@ int MockUDPClientSocket::GetLocalAddress(IPEndPoint* address) const {
void MockUDPClientSocket::UseNonBlockingIO() {}
-const BoundNetLog& MockUDPClientSocket::NetLog() const {
+const NetLogWithSource& MockUDPClientSocket::NetLog() const {
return net_log_;
}
@@ -1628,7 +1627,7 @@ int MockTransportClientSocketPool::RequestSocket(
RespectLimits respect_limits,
ClientSocketHandle* handle,
const CompletionCallback& callback,
- const BoundNetLog& net_log) {
+ const NetLogWithSource& net_log) {
last_request_priority_ = priority;
std::unique_ptr<StreamSocket> socket =
client_socket_factory_->CreateTransportClientSocket(
@@ -1677,7 +1676,7 @@ int MockSOCKSClientSocketPool::RequestSocket(const std::string& group_name,
RespectLimits respect_limits,
ClientSocketHandle* handle,
const CompletionCallback& callback,
- const BoundNetLog& net_log) {
+ const NetLogWithSource& net_log) {
return transport_pool_->RequestSocket(group_name, socket_params, priority,
respect_limits, handle, callback,
net_log);
@@ -1135,7 +1133,8 @@ MockSSLClientSocket::MockSSLClientSocket(
SSLSocketDataProvider* data)
: MockClientSocket(
- // Have to use the right BoundNetLog for LoadTimingInfo regression
+ // Have to use the right NetLogWithSource for LoadTimingInfo
+ // regression
// tests.
transport_socket->socket()->NetLog()),

Powered by Google App Engine
This is Rietveld 408576698